import { Container, Entity, ItemStack } from "@minecraft/server";
/**
 * Replace {@link ItemStack} in a {@link Container}
 * @param item The {@link ItemStack} or {@link ItemStack.typeId} to be replaced.
 * if it's undefined, every empty slot will be filled.
 * @param newItem the new {@link ItemStack}.
 * if it's undefined, the matched slot will be cleared.
 * @param container the {@link Container} which will be searched.
 */
export declare function replaceItemStack(item: ItemStack | string | undefined, newItem: ItemStack | string | undefined, container: Container): number;
/**
 * Damage an {@link ItemStack}.
 * @param item The {@link ItemStack} to be damaged.
 * @param value The durability to be removed.
 * @param entity The optional {@link Entity} which breaks this tool.
 * @returns the damaged {@link ItemStack}.
 */
export declare function consumeDurability(item: ItemStack, value: number, entity?: Entity): ItemStack | undefined;
/**
 * Edit the amount of an {@link ItemStack}.
 * @param item The {@link ItemStack}.
 * @param value The amount to be removed.
 * @returns the new {@link ItemStack}.
 * @throws SapiError if amount is not enough to be removed.
 * @throws SapiError if max amount is not high enough.
 */
export declare function consumeAmount(item: ItemStack, value: number): ItemStack | undefined;
export declare function getItemAmountInContainer(container: Container, item: string): number;
export declare function removeItemInContainer(container: Container, itemId: string, amount: number): void;
